readFileStream method
Reads the contents of a file from the given uri and returns a stream of bytes.
If bufferSize is provided, the stream will read data in chunks of bufferSize bytes.
If start is provided, the stream will start reading from the given position.
Implementation
Future<Stream<Uint8List>> readFileStream(
String uri, {
int? bufferSize,
int? start,
}) async {
return SafStreamPlatform.instance.readFileStream(
uri,
bufferSize: bufferSize,
start: start,
);
}